@@ -79,6 +79,7 @@ type serverConfig struct {
 	DefaultJWTSVIDTTL            string             `hcl:"default_jwt_svid_ttl"`
 	Experimental                 experimentalConfig `hcl:"experimental"`
 	Federation                   *federationConfig  `hcl:"federation"`
+	DisableJWTSVIDs              bool               `hcl:"disable_jwt_svids"`
 	JWTIssuer                    string             `hcl:"jwt_issuer"`
 	JWTKeyType                   string             `hcl:"jwt_key_type"`
 	LogFile                      string             `hcl:"log_file"`
@@ -694,6 +695,11 @@ func NewServerConfig(c *Config, logOptions []log.Option, allowUnknownConfig bool
 		}
 	}
 
+	if c.Server.DisableJWTSVIDs {
+		sc.Log.Info("JWT-SVID profile is disabled")
+	}
+	sc.DisableJWTSVIDs = c.Server.DisableJWTSVIDs
+
 	if !allowUnknownConfig {
 		if err := checkForUnknownConfig(c, sc.Log); err != nil {
 			return nil, err
