@@ -139,102 +139,87 @@ func (a *Agent) Run(ctx context.Context) error {
 		}
 	}
 
-	if a.c.RetryBootstrap {
-		attBackoffClock := clock.New()
-		backoffTime := bootstrapBackoffMaxElapsedTime
-		if a.c.RebootstrapMode != RebootstrapNever {
-			backoffTime = rebootstrapBackoffMaxElapsedTime
-		}
-		attBackoff := backoff.NewBackoff(
-			attBackoffClock,
-			bootstrapBackoffInterval,
-			backoff.WithMaxElapsedTime(backoffTime),
-		)
+	attBackoffClock := clock.New()
+	backoffTime := bootstrapBackoffMaxElapsedTime
+	if a.c.RebootstrapMode != RebootstrapNever {
+		backoffTime = rebootstrapBackoffMaxElapsedTime
+	}
+	attBackoff := backoff.NewBackoff(
+		attBackoffClock,
+		bootstrapBackoffInterval,
+		backoff.WithMaxElapsedTime(backoffTime),
+	)
 
-		for {
-			insecureBootstrap := false
-			bootstrapTrustBundle, err := sto.LoadBundle()
-			if errors.Is(err, storage.ErrNotCached) {
-				bootstrapTrustBundle, insecureBootstrap, err = a.c.TrustBundleSources.GetBundle()
-			}
-			if err == nil {
-				as, err = a.attest(ctx, sto, cat, metrics, nodeAttestor, bootstrapTrustBundle, insecureBootstrap)
-				if err == nil {
-					err = a.c.TrustBundleSources.SetSuccess()
-					if err != nil {
-						return err
-					}
-					if a.c.RebootstrapMode != RebootstrapNever {
-						_, reattestable, err := sto.LoadSVID()
-						if err == nil && !reattestable {
-							if a.c.RebootstrapMode == RebootstrapAlways {
-								return errors.New("you have requested rebootstrap support but the NodeAttestor plugin or the spire server configuration is not allowing it")
-							} else {
-								a.c.Log.Warn("you have requested rebootstrap support but the NodeAttestor plugin or the spire server configuration is not allowing it. Disabling")
-								a.c.RebootstrapMode = RebootstrapNever
-							}
-						}
-					}
-					break
-				}
-
-				if x509util.IsUnknownAuthorityError(err) {
-					if a.c.TrustBundleSources.IsBootstrap() {
-						a.c.Log.Info("Trust Bandle and Server dont agree.... bootstrapping again")
-					} else if a.c.RebootstrapMode != RebootstrapNever {
-						startTime, err := a.c.TrustBundleSources.GetStartTime()
-						if err != nil {
-							return nil
-						}
-						seconds := time.Since(startTime)
-						if seconds < a.c.RebootstrapDelay {
-							a.c.Log.WithFields(logrus.Fields{
-								"time left": a.c.RebootstrapDelay - seconds,
-							}).Info("Trust Bandle and Server dont agree.... Ignoring for now.")
-						} else {
-							a.c.Log.Warn("Trust Bandle and Server dont agree.... rebootstrapping")
-							err = sto.StoreBundle(nil)
-							if err != nil {
-								return err
-							}
-						}
-					}
-				}
-
-				if status.Code(err) == codes.PermissionDenied {
-					return err
-				}
-			}
-
-			nextDuration := attBackoff.NextBackOff()
-			if nextDuration == backoff.Stop {
-				return err
-			}
-
-			a.c.Log.WithFields(logrus.Fields{
-				telemetry.Error:         err,
-				telemetry.RetryInterval: nextDuration,
-			}).Warn("Failed to retrieve attestation result")
-
-			select {
-			case <-ctx.Done():
-				return ctx.Err()
-			case <-attBackoffClock.After(nextDuration):
-				continue
-			}
-		}
-	} else {
+	for {
 		insecureBootstrap := false
 		bootstrapTrustBundle, err := sto.LoadBundle()
 		if errors.Is(err, storage.ErrNotCached) {
 			bootstrapTrustBundle, insecureBootstrap, err = a.c.TrustBundleSources.GetBundle()
 		}
-		if err != nil {
+		if err == nil {
+			as, err = a.attest(ctx, sto, cat, metrics, nodeAttestor, bootstrapTrustBundle, insecureBootstrap)
+			if err == nil {
+				err = a.c.TrustBundleSources.SetSuccess()
+				if err != nil {
+					return err
+				}
+				if a.c.RebootstrapMode != RebootstrapNever {
+					_, reattestable, err := sto.LoadSVID()
+					if err == nil && !reattestable {
+						if a.c.RebootstrapMode == RebootstrapAlways {
+							return errors.New("you have requested rebootstrap support but the NodeAttestor plugin or the spire server configuration is not allowing it")
+						} else {
+							a.c.Log.Warn("you have requested rebootstrap support but the NodeAttestor plugin or the spire server configuration is not allowing it. Disabling")
+							a.c.RebootstrapMode = RebootstrapNever
+						}
+					}
+				}
+				break
+			}
+
+			if x509util.IsUnknownAuthorityError(err) {
+				if a.c.TrustBundleSources.IsBootstrap() {
+					a.c.Log.Info("Trust Bundle and Server dont agree.... bootstrapping again")
+				} else if a.c.RebootstrapMode != RebootstrapNever {
+					startTime, err := a.c.TrustBundleSources.GetStartTime()
+					if err != nil {
+						return nil
+					}
+					seconds := time.Since(startTime)
+					if seconds < a.c.RebootstrapDelay {
+						a.c.Log.WithFields(logrus.Fields{
+							"time left": a.c.RebootstrapDelay - seconds,
+						}).Info("Trust Bundle and Server dont agree.... Ignoring for now.")
+					} else {
+						a.c.Log.Warn("Trust Bundle and Server dont agree.... rebootstrapping")
+						err = sto.StoreBundle(nil)
+						if err != nil {
+							return err
+						}
+					}
+				}
+			}
+
+			if status.Code(err) == codes.PermissionDenied {
+				return err
+			}
+		}
+
+		nextDuration := attBackoff.NextBackOff()
+		if nextDuration == backoff.Stop {
 			return err
 		}
-		as, err = a.attest(ctx, sto, cat, metrics, nodeAttestor, bootstrapTrustBundle, insecureBootstrap)
-		if err != nil {
-			return err
+
+		a.c.Log.WithFields(logrus.Fields{
+			telemetry.Error:         err,
+			telemetry.RetryInterval: nextDuration,
+		}).Warn("Failed to retrieve attestation result")
+
+		select {
+		case <-ctx.Done():
+			return ctx.Err()
+		case <-attBackoffClock.After(nextDuration):
+			continue
 		}
 	}
 
@@ -383,73 +368,66 @@ func (a *Agent) newManager(ctx context.Context, sto storage.Storage, cat catalog
 	}
 
 	mgr := manager.New(config)
-	if a.c.RetryBootstrap {
-		initBackoffClock := clock.New()
-		backoffTime := bootstrapBackoffMaxElapsedTime
-		if a.c.RebootstrapMode != RebootstrapNever {
-			backoffTime = rebootstrapBackoffMaxElapsedTime
-		}
-		initBackoff := backoff.NewBackoff(
-			initBackoffClock,
-			bootstrapBackoffInterval,
-			backoff.WithMaxElapsedTime(backoffTime),
-		)
+	initBackoffClock := clock.New()
+	backoffTime := bootstrapBackoffMaxElapsedTime
+	if a.c.RebootstrapMode != RebootstrapNever {
+		backoffTime = rebootstrapBackoffMaxElapsedTime
+	}
+	initBackoff := backoff.NewBackoff(
+		initBackoffClock,
+		bootstrapBackoffInterval,
+		backoff.WithMaxElapsedTime(backoffTime),
+	)
 
-		for {
-			err := mgr.Initialize(ctx)
-			if err == nil {
-				err = a.c.TrustBundleSources.SetSuccessIfRunning()
+	for {
+		err := mgr.Initialize(ctx)
+		if err == nil {
+			err = a.c.TrustBundleSources.SetSuccessIfRunning()
+			if err != nil {
+				return nil, err
+			}
+			return mgr, nil
+		}
+		if x509util.IsUnknownAuthorityError(err) && a.c.RebootstrapMode != RebootstrapNever {
+			startTime, err := a.c.TrustBundleSources.GetStartTime()
+			if err != nil {
+				return nil, err
+			}
+			seconds := time.Since(startTime)
+			if seconds < a.c.RebootstrapDelay {
+				a.c.Log.WithFields(logrus.Fields{
+					"time left": a.c.RebootstrapDelay - seconds,
+				}).Info("Trust Bundle and Server dont agree.... Ignoring for now.")
+			} else {
+				a.c.Log.Info("Trust Bundle and Server dont agree.... rebootstrapping")
+				err = a.c.TrustBundleSources.SetForceRebootstrap()
 				if err != nil {
 					return nil, err
 				}
-				return mgr, nil
-			}
-			if x509util.IsUnknownAuthorityError(err) && a.c.RebootstrapMode != RebootstrapNever {
-				startTime, err := a.c.TrustBundleSources.GetStartTime()
-				if err != nil {
-					return nil, err
-				}
-				seconds := time.Since(startTime)
-				if seconds < a.c.RebootstrapDelay {
-					a.c.Log.WithFields(logrus.Fields{
-						"time left": a.c.RebootstrapDelay - seconds,
-					}).Info("Trust Bandle and Server dont agree.... Ignoring for now.")
-				} else {
-					a.c.Log.Info("Trust Bandle and Server dont agree.... rebootstrapping")
-					err = a.c.TrustBundleSources.SetForceRebootstrap()
-					if err != nil {
-						return nil, err
-					}
-					return nil, errors.New("Agent needs to rebootstrap. shutting down")
-				}
-			}
-
-			if nodeutil.ShouldAgentReattest(err) || nodeutil.ShouldAgentShutdown(err) {
-				return nil, err
-			}
-
-			nextDuration := initBackoff.NextBackOff()
-			if nextDuration == backoff.Stop {
-				return nil, err
-			}
-
-			a.c.Log.WithFields(logrus.Fields{
-				telemetry.Error:         err,
-				telemetry.RetryInterval: nextDuration,
-			}).Warn("Failed to initialize manager")
-
-			select {
-			case <-ctx.Done():
-				return nil, ctx.Err()
-			case <-initBackoffClock.After(nextDuration):
-				continue
+				return nil, errors.New("Agent needs to rebootstrap. shutting down")
 			}
 		}
-	} else {
-		if err := mgr.Initialize(ctx); err != nil {
+
+		if nodeutil.ShouldAgentReattest(err) || nodeutil.ShouldAgentShutdown(err) {
 			return nil, err
 		}
-		return mgr, nil
+
+		nextDuration := initBackoff.NextBackOff()
+		if nextDuration == backoff.Stop {
+			return nil, err
+		}
+
+		a.c.Log.WithFields(logrus.Fields{
+			telemetry.Error:         err,
+			telemetry.RetryInterval: nextDuration,
+		}).Warn("Failed to initialize manager")
+
+		select {
+		case <-ctx.Done():
+			return nil, ctx.Err()
+		case <-initBackoffClock.After(nextDuration):
+			continue
+		}
 	}
 }
 
