@@ -1425,7 +1425,7 @@ func requireSecrets(t *testing.T, resp *discovery_v3.DiscoveryResponse, expected
 	var actualSecrets []*tls_v3.Secret
 	for _, resource := range resp.Resources {
 		secret := new(tls_v3.Secret)
-		require.NoError(t, resource.UnmarshalTo(secret)) //nolint: scopelint // pointer to resource isn't held
+		require.NoError(t, resource.UnmarshalTo(secret))
 		actualSecrets = append(actualSecrets, secret)
 	}
 
