@@ -72,6 +72,10 @@ func (m *KeyManager) Configure(_ context.Context, req *configv1.ConfigureRequest
 		return nil, status.Error(codes.InvalidArgument, "directory must be configured")
 	}
 
+	if err := m.verifyDirectory(config.Directory); err != nil {
+		return nil, status.Errorf(codes.FailedPrecondition, "directory validation failed: %v", err)
+	}
+
 	m.mu.Lock()
 	defer m.mu.Unlock()
 
@@ -94,6 +98,20 @@ func (m *KeyManager) configure(config *configuration) error {
 	return nil
 }
 
+func (m *KeyManager) verifyDirectory(dir string) error {
+	if err := os.MkdirAll(dir, 0700); err != nil {
+		return err
+	}
+
+	probe := filepath.Join(dir, ".probe")
+	if err := os.WriteFile(probe, []byte{}, 0600); err != nil {
+		return err
+	}
+	os.Remove(probe)
+
+	return nil
+}
+
 func (m *KeyManager) loadEntries(dir string) error {
 	// Load the entries from the keys file.
 	entries, err := loadEntries(keysPath(dir))
