@@ -49,14 +49,39 @@ var (
 
 func TestGetJWTAuthorityState(t *testing.T) {
 	for _, tt := range []struct {
-		name        string
-		currentSlot *fakeSlot
-		nextSlot    *fakeSlot
-		expectLogs  []spiretest.LogEntry
-		expectCode  codes.Code
-		expectMsg   string
-		expectResp  *localauthorityv1.GetJWTAuthorityStateResponse
+		name            string
+		disableJWTSVIDs bool
+		currentSlot     *fakeSlot
+		nextSlot        *fakeSlot
+		expectLogs      []spiretest.LogEntry
+		expectCode      codes.Code
+		expectMsg       string
+		expectResp      *localauthorityv1.GetJWTAuthorityStateResponse
 	}{
+		{
+			name:            "JWT is disabled",
+			disableJWTSVIDs: true,
+			currentSlot:     &fakeSlot{},
+			nextSlot:        &fakeSlot{},
+			expectCode:      codes.Unimplemented,
+			expectMsg:       "JWT functionality is disabled",
+			expectLogs: []spiretest.LogEntry{
+				{
+					Level:   logrus.ErrorLevel,
+					Message: "JWT functionality is disabled",
+				},
+				{
+					Level:   logrus.InfoLevel,
+					Message: "API accessed",
+					Data: logrus.Fields{
+						telemetry.Status:        "error",
+						telemetry.Type:          "audit",
+						telemetry.StatusCode:    "Unimplemented",
+						telemetry.StatusMessage: "JWT functionality is disabled",
+					},
+				},
+			},
+		},
 		{
 			name:        "current is set",
 			currentSlot: createSlot(journal.Status_ACTIVE, authorityIDKeyA, keyA.Public(), notAfterCurrent),
@@ -206,6 +231,7 @@ func TestGetJWTAuthorityState(t *testing.T) {
 		test := setupServiceTest(t)
 		defer test.Cleanup()
 
+		test.ca.disableJWTSVIDs = tt.disableJWTSVIDs
 		test.ca.currentJWTKeySlot = tt.currentSlot
 		test.ca.nextJWTKeySlot = tt.nextSlot
 
@@ -219,15 +245,40 @@ func TestGetJWTAuthorityState(t *testing.T) {
 
 func TestPrepareJWTAuthority(t *testing.T) {
 	for _, tt := range []struct {
-		name        string
-		currentSlot *fakeSlot
-		prepareErr  error
-		nextSlot    *fakeSlot
-		expectLogs  []spiretest.LogEntry
-		expectCode  codes.Code
-		expectMsg   string
-		expectResp  *localauthorityv1.PrepareJWTAuthorityResponse
+		name            string
+		disableJWTSVIDs bool
+		currentSlot     *fakeSlot
+		prepareErr      error
+		nextSlot        *fakeSlot
+		expectLogs      []spiretest.LogEntry
+		expectCode      codes.Code
+		expectMsg       string
+		expectResp      *localauthorityv1.PrepareJWTAuthorityResponse
 	}{
+		{
+			name:            "JWT is disabled",
+			disableJWTSVIDs: true,
+			currentSlot:     &fakeSlot{},
+			nextSlot:        &fakeSlot{},
+			expectCode:      codes.Unimplemented,
+			expectMsg:       "JWT functionality is disabled",
+			expectLogs: []spiretest.LogEntry{
+				{
+					Level:   logrus.ErrorLevel,
+					Message: "JWT functionality is disabled",
+				},
+				{
+					Level:   logrus.InfoLevel,
+					Message: "API accessed",
+					Data: logrus.Fields{
+						telemetry.Status:        "error",
+						telemetry.Type:          "audit",
+						telemetry.StatusCode:    "Unimplemented",
+						telemetry.StatusMessage: "JWT functionality is disabled",
+					},
+				},
+			},
+		},
 		{
 			name:        "using next to prepare",
 			currentSlot: createSlot(journal.Status_ACTIVE, authorityIDKeyA, keyA.Public(), notAfterCurrent),
@@ -304,6 +355,7 @@ func TestPrepareJWTAuthority(t *testing.T) {
 			test := setupServiceTest(t)
 			defer test.Cleanup()
 
+			test.ca.disableJWTSVIDs = tt.disableJWTSVIDs
 			test.ca.currentJWTKeySlot = tt.currentSlot
 			test.ca.nextJWTKeySlot = tt.nextSlot
 			test.ca.prepareJWTKeyErr = tt.prepareErr
@@ -319,9 +371,10 @@ func TestPrepareJWTAuthority(t *testing.T) {
 
 func TestActivateJWTAuthority(t *testing.T) {
 	for _, tt := range []struct {
-		name        string
-		currentSlot *fakeSlot
-		nextSlot    *fakeSlot
+		name            string
+		disableJWTSVIDs bool
+		currentSlot     *fakeSlot
+		nextSlot        *fakeSlot
 
 		rotateCalled  bool
 		keyToActivate string
@@ -330,6 +383,30 @@ func TestActivateJWTAuthority(t *testing.T) {
 		expectMsg     string
 		expectResp    *localauthorityv1.ActivateJWTAuthorityResponse
 	}{
+		{
+			name:            "JWT is disabled",
+			disableJWTSVIDs: true,
+			currentSlot:     &fakeSlot{},
+			nextSlot:        &fakeSlot{},
+			expectCode:      codes.Unimplemented,
+			expectMsg:       "JWT functionality is disabled",
+			expectLogs: []spiretest.LogEntry{
+				{
+					Level:   logrus.ErrorLevel,
+					Message: "JWT functionality is disabled",
+				},
+				{
+					Level:   logrus.InfoLevel,
+					Message: "API accessed",
+					Data: logrus.Fields{
+						telemetry.Status:        "error",
+						telemetry.Type:          "audit",
+						telemetry.StatusCode:    "Unimplemented",
+						telemetry.StatusMessage: "JWT functionality is disabled",
+					},
+				},
+			},
+		},
 		{
 			name:          "activate successfully",
 			currentSlot:   createSlot(journal.Status_ACTIVE, authorityIDKeyA, keyA.Public(), notAfterCurrent),
@@ -439,6 +516,7 @@ func TestActivateJWTAuthority(t *testing.T) {
 			test := setupServiceTest(t)
 			defer test.Cleanup()
 
+			test.ca.disableJWTSVIDs = tt.disableJWTSVIDs
 			test.ca.currentJWTKeySlot = tt.currentSlot
 			test.ca.nextJWTKeySlot = tt.nextSlot
 
@@ -470,10 +548,11 @@ func TestTaintJWTAuthority(t *testing.T) {
 	nextKeyNotAfter := clk.Now().Add(2 * time.Minute)
 
 	for _, tt := range []struct {
-		name        string
-		currentSlot *fakeSlot
-		nextSlot    *fakeSlot
-		keyToTaint  string
+		name            string
+		disableJWTSVIDs bool
+		currentSlot     *fakeSlot
+		nextSlot        *fakeSlot
+		keyToTaint      string
 
 		expectLogs       []spiretest.LogEntry
 		expectCode       codes.Code
@@ -481,6 +560,30 @@ func TestTaintJWTAuthority(t *testing.T) {
 		expectResp       *localauthorityv1.TaintJWTAuthorityResponse
 		nextKeyIsTainted bool
 	}{
+		{
+			name:            "JWT is disabled",
+			disableJWTSVIDs: true,
+			currentSlot:     &fakeSlot{},
+			nextSlot:        &fakeSlot{},
+			expectCode:      codes.Unimplemented,
+			expectMsg:       "JWT functionality is disabled",
+			expectLogs: []spiretest.LogEntry{
+				{
+					Level:   logrus.ErrorLevel,
+					Message: "JWT functionality is disabled",
+				},
+				{
+					Level:   logrus.InfoLevel,
+					Message: "API accessed",
+					Data: logrus.Fields{
+						telemetry.Status:        "error",
+						telemetry.Type:          "audit",
+						telemetry.StatusCode:    "Unimplemented",
+						telemetry.StatusMessage: "JWT functionality is disabled",
+					},
+				},
+			},
+		},
 		{
 			name:        "taint old authority",
 			currentSlot: createSlot(journal.Status_ACTIVE, currentAuthorityID, currentKey.Public(), currentKeyNotAfter),
@@ -652,6 +755,7 @@ func TestTaintJWTAuthority(t *testing.T) {
 		test := setupServiceTest(t)
 		defer test.Cleanup()
 
+		test.ca.disableJWTSVIDs = tt.disableJWTSVIDs
 		test.ca.currentJWTKeySlot = tt.currentSlot
 		test.ca.nextJWTKeySlot = tt.nextSlot
 		_, err := test.ds.CreateBundle(ctx, &common.Bundle{
@@ -704,17 +808,42 @@ func TestRevokeJWTAuthority(t *testing.T) {
 	oldKeyNotAfter := clk.Now()
 
 	for _, tt := range []struct {
-		name          string
-		currentSlot   *fakeSlot
-		nextSlot      *fakeSlot
-		keyToRevoke   string
-		noTaintedKeys bool
+		name            string
+		disableJWTSVIDs bool
+		currentSlot     *fakeSlot
+		nextSlot        *fakeSlot
+		keyToRevoke     string
+		noTaintedKeys   bool
 
 		expectLogs []spiretest.LogEntry
 		expectCode codes.Code
 		expectMsg  string
 		expectResp *localauthorityv1.RevokeJWTAuthorityResponse
 	}{
+		{
+			name:            "JWT is disabled",
+			disableJWTSVIDs: true,
+			currentSlot:     &fakeSlot{},
+			nextSlot:        &fakeSlot{},
+			expectCode:      codes.Unimplemented,
+			expectMsg:       "JWT functionality is disabled",
+			expectLogs: []spiretest.LogEntry{
+				{
+					Level:   logrus.ErrorLevel,
+					Message: "JWT functionality is disabled",
+				},
+				{
+					Level:   logrus.InfoLevel,
+					Message: "API accessed",
+					Data: logrus.Fields{
+						telemetry.Status:        "error",
+						telemetry.Type:          "audit",
+						telemetry.StatusCode:    "Unimplemented",
+						telemetry.StatusMessage: "JWT functionality is disabled",
+					},
+				},
+			},
+		},
 		{
 			name:        "revoke authority from parameter",
 			currentSlot: createSlot(journal.Status_ACTIVE, currentAuthorityID, currentKey.Public(), currentKeyNotAfter),
@@ -892,6 +1021,7 @@ func TestRevokeJWTAuthority(t *testing.T) {
 			test := setupServiceTest(t)
 			defer test.Cleanup()
 
+			test.ca.disableJWTSVIDs = tt.disableJWTSVIDs
 			test.ca.currentJWTKeySlot = tt.currentSlot
 			test.ca.nextJWTKeySlot = tt.nextSlot
 
@@ -2484,6 +2614,7 @@ type fakeCAManager struct {
 	rotateJWTKeyCalled bool
 
 	prepareJWTKeyErr error
+	disableJWTSVIDs  bool
 
 	prepareX509CAErr    error
 	isUpstreamAuthority bool
@@ -2536,6 +2667,10 @@ func (m *fakeCAManager) RotateX509CA(context.Context) {
 	m.rotateX509CACalled = true
 }
 
+func (m *fakeCAManager) IsJWTSVIDsDisabled() bool {
+	return m.disableJWTSVIDs
+}
+
 type fakeSlot struct {
 	manager.Slot
 
