@@ -69,23 +69,25 @@ type AuthorityManager interface {
 	PrepareX509CA(ctx context.Context) error
 	RotateX509CA(ctx context.Context)
 	IsUpstreamAuthority() bool
+	IsJWTSVIDsDisabled() bool
 	PublishJWTKey(ctx context.Context, jwtKey *common.PublicKey) ([]*common.PublicKey, error)
 	NotifyTaintedX509Authority(ctx context.Context, authorityID string) error
 	SubscribeToLocalBundle(ctx context.Context) error
 }
 
 type Config struct {
-	CredBuilder   *credtemplate.Builder
-	CredValidator *credvalidator.Validator
-	CA            ManagedCA
-	Catalog       catalog.Catalog
-	TrustDomain   spiffeid.TrustDomain
-	X509CAKeyType keymanager.KeyType
-	JWTKeyType    keymanager.KeyType
-	Dir           string
-	Log           logrus.FieldLogger
-	Metrics       telemetry.Metrics
-	Clock         clock.Clock
+	CredBuilder     *credtemplate.Builder
+	CredValidator   *credvalidator.Validator
+	CA              ManagedCA
+	Catalog         catalog.Catalog
+	TrustDomain     spiffeid.TrustDomain
+	X509CAKeyType   keymanager.KeyType
+	DisableJWTSVIDs bool
+	JWTKeyType      keymanager.KeyType
+	Dir             string
+	Log             logrus.FieldLogger
+	Metrics         telemetry.Metrics
+	Clock           clock.Clock
 }
 
 type Manager struct {
@@ -205,6 +207,10 @@ func (m *Manager) NotifyTaintedX509Authority(ctx context.Context, authorityID st
 	return nil
 }
 
+func (m *Manager) IsJWTSVIDsDisabled() bool {
+	return m.c.DisableJWTSVIDs
+}
+
 func (m *Manager) GetCurrentX509CASlot() Slot {
 	m.x509CAMutex.RLock()
 	defer m.x509CAMutex.RUnlock()
@@ -323,6 +329,10 @@ func (m *Manager) GetNextJWTKeySlot() Slot {
 }
 
 func (m *Manager) PrepareJWTKey(ctx context.Context) (err error) {
+	if m.IsJWTSVIDsDisabled() {
+		return nil
+	}
+
 	counter := telemetry_server.StartServerCAManagerPrepareJWTKeyCall(m.c.Metrics)
 	defer counter.Done(&err)
 
@@ -383,6 +393,9 @@ func (m *Manager) PrepareJWTKey(ctx context.Context) (err error) {
 }
 
 func (m *Manager) ActivateJWTKey(ctx context.Context) {
+	if m.IsJWTSVIDsDisabled() {
+		return
+	}
 	m.jwtKeyMutex.RLock()
 	defer m.jwtKeyMutex.RUnlock()
 
@@ -390,6 +403,10 @@ func (m *Manager) ActivateJWTKey(ctx context.Context) {
 }
 
 func (m *Manager) RotateJWTKey(ctx context.Context) {
+	if m.IsJWTSVIDsDisabled() {
+		return
+	}
+
 	m.jwtKeyMutex.Lock()
 	defer m.jwtKeyMutex.Unlock()
 
