@@ -390,26 +390,6 @@ func TestBuildDownstreamX509CATemplate(t *testing.T) {
 			overrideExpected: func(expected *x509.Certificate) {
 			},
 		},
-		{
-			desc: "default legacy TTL",
-			overrideConfig: func(config *credtemplate.Config) {
-				config.UseLegacyDownstreamX509CATTL = true
-			},
-			overrideExpected: func(expected *x509.Certificate) {
-				expected.NotAfter = now.Add(credtemplate.DefaultX509SVIDTTL)
-			},
-		},
-		{
-			desc: "override X509SVIDTTL with legacy TTL",
-			overrideConfig: func(config *credtemplate.Config) {
-				// Downstream CAs have historically been signed using the default X509-SVID TTL
-				config.X509SVIDTTL = credtemplate.DefaultX509SVIDTTL * 2
-				config.UseLegacyDownstreamX509CATTL = true
-			},
-			overrideExpected: func(expected *x509.Certificate) {
-				expected.NotAfter = now.Add(credtemplate.DefaultX509SVIDTTL * 2)
-			},
-		},
 		{
 			desc: "with ttl",
 			overrideParams: func(params *credtemplate.DownstreamX509CAParams) {
@@ -686,7 +666,8 @@ func TestBuildAgentX509SVIDTemplate(t *testing.T) {
 				params.PublicKey = nil
 			},
 			expectErr: "x509: unsupported public key type: <nil>",
-		}, {
+		},
+		{
 			desc: "override X509SVIDTTL",
 			overrideConfig: func(config *credtemplate.Config) {
 				config.X509SVIDTTL = credtemplate.DefaultX509SVIDTTL * 2
