@@ -11,6 +11,7 @@ import (
 
 	"github.com/spiffe/go-spiffe/v2/spiffetls/tlsconfig"
 	"github.com/spiffe/spire/pkg/server/cache/entrycache"
+	"github.com/spiffe/spire/pkg/server/cache/nodecache"
 	"github.com/spiffe/spire/pkg/server/endpoints/bundle"
 	"golang.org/x/net/http2"
 	"google.golang.org/grpc"
@@ -90,6 +91,7 @@ type Endpoints struct {
 	Log                          logrus.FieldLogger
 	Metrics                      telemetry.Metrics
 	RateLimit                    RateLimitConfig
+	NodeCacheRebuildTask         func(context.Context) error
 	EntryFetcherCacheRebuildTask func(context.Context) error
 	EntryFetcherPruneEventsTask  func(context.Context) error
 	CertificateReloadTask        func(context.Context) error
@@ -97,6 +99,8 @@ type Endpoints struct {
 	AuthPolicyEngine             *authpolicy.Engine
 	AdminIDs                     []spiffeid.ID
 	TLSPolicy                    tlspolicy.Policy
+	MaxAttestedNodeInfoStaleness time.Duration
+	nodeCache                    api.AttestedNodeCache
 
 	hooks struct {
 		// test hook used to indicate that is listening
@@ -157,14 +161,20 @@ func New(ctx context.Context, c Config) (*Endpoints, error) {
 
 	ds := c.Catalog.GetDataStore()
 
+	nodeCache, err := nodecache.New(ctx, c.Log, ds, c.Clock, true, c.MaxAttestedNodeInfoStaleness != 0)
+	if err != nil {
+		return nil, err
+	}
+
 	var ef api.AuthorizedEntryFetcher
-	var cacheRebuildTask, pruneEventsTask func(context.Context) error
+	var cacheRebuildTask, nodeCacheRebuildTask, pruneEventsTask func(context.Context) error
 	if c.EventsBasedCache {
 		efEventsBasedCache, err := NewAuthorizedEntryFetcherEvents(ctx, AuthorizedEntryFetcherEventsConfig{
 			log:                     c.Log,
 			metrics:                 c.Metrics,
 			clk:                     c.Clock,
 			ds:                      ds,
+			nodeCache:               nodeCache,
 			cacheReloadInterval:     c.CacheReloadInterval,
 			fullCacheReloadInterval: c.FullCacheReloadInterval,
 			pruneEventsOlderThan:    c.PruneEventsOlderThan,
@@ -175,6 +185,7 @@ func New(ctx context.Context, c Config) (*Endpoints, error) {
 		}
 		cacheRebuildTask = efEventsBasedCache.RunUpdateCacheTask
 		pruneEventsTask = efEventsBasedCache.PruneEventsTask
+		nodeCacheRebuildTask = nodeCache.PeriodicRebuild
 		ef = efEventsBasedCache
 	} else {
 		buildCacheFn := func(ctx context.Context) (_ entrycache.Cache, err error) {
@@ -189,6 +200,8 @@ func New(ctx context.Context, c Config) (*Endpoints, error) {
 		}
 		cacheRebuildTask = efFullCache.RunRebuildCacheTask
 		pruneEventsTask = efFullCache.PruneEventsTask
+		// cacheRebuildTask will take care of rebuilding the node cache
+		nodeCacheRebuildTask = func(ctx context.Context) error { return nil }
 		ef = efFullCache
 	}
 
@@ -206,6 +219,7 @@ func New(ctx context.Context, c Config) (*Endpoints, error) {
 		Log:                          c.Log,
 		Metrics:                      c.Metrics,
 		RateLimit:                    c.RateLimit,
+		NodeCacheRebuildTask:         nodeCacheRebuildTask,
 		EntryFetcherCacheRebuildTask: cacheRebuildTask,
 		EntryFetcherPruneEventsTask:  pruneEventsTask,
 		CertificateReloadTask:        certificateReloadTask,
@@ -213,6 +227,9 @@ func New(ctx context.Context, c Config) (*Endpoints, error) {
 		AuthPolicyEngine:             c.AuthPolicyEngine,
 		AdminIDs:                     c.AdminIDs,
 		TLSPolicy:                    c.TLSPolicy,
+		MaxAttestedNodeInfoStaleness: c.MaxAttestedNodeInfoStaleness,
+		nodeCache:                    nodeCache,
+
 		hooks: struct {
 			listening chan struct{}
 		}{
@@ -259,6 +276,7 @@ func (e *Endpoints) ListenAndServe(ctx context.Context) error {
 			return e.runLocalAccess(ctx, udsServer)
 		},
 		e.EntryFetcherCacheRebuildTask,
+		e.NodeCacheRebuildTask,
 	}
 
 	if e.BundleEndpointServer != nil {
@@ -433,7 +451,7 @@ func (e *Endpoints) getTLSConfig(ctx context.Context) func(*tls.ClientHelloInfo)
 func (e *Endpoints) makeInterceptors() (grpc.UnaryServerInterceptor, grpc.StreamServerInterceptor) {
 	log := e.Log.WithField(telemetry.SubsystemName, "api")
 
-	return middleware.Interceptors(Middleware(log, e.Metrics, e.DataStore, clock.New(), e.RateLimit, e.AuthPolicyEngine, e.AuditLogEnabled, e.AdminIDs))
+	return middleware.Interceptors(Middleware(log, e.Metrics, e.DataStore, e.nodeCache, e.MaxAttestedNodeInfoStaleness, clock.New(), e.RateLimit, e.AuthPolicyEngine, e.AuditLogEnabled, e.AdminIDs))
 }
 
 func (e *Endpoints) triggerListeningHook() {
