@@ -5,6 +5,7 @@ import (
 	"crypto/tls"
 	"errors"
 	"net"
+	"os"
 	"reflect"
 	"strings"
 	"sync"
@@ -263,6 +264,14 @@ func TestListenAndServe(t *testing.T) {
 		return conn
 	}
 
+	// Await /tmp/spire-test-*/sockets to become available (within 10s)
+	// Avoids flaky tests in CI, where we occasionally see failures
+	// due to the socket not being ready when first used by the test
+	require.Eventually(t, func() bool {
+		_, err := os.Stat(endpoints.LocalAddr.String())
+		return err == nil
+	}, 10*time.Second, 10*time.Millisecond, "socket %q not available", endpoints.LocalAddr.String())
+
 	target, err := util.GetTargetName(endpoints.LocalAddr)
 	require.NoError(t, err)
 
@@ -626,6 +635,7 @@ func testBundleAPI(ctx context.Context, t *testing.T, conns testConns) {
 			"GetBundle":                  true,
 			"AppendBundle":               true,
 			"PublishJWTAuthority":        false,
+			"PublishWITAuthority":        false,
 			"CountBundles":               true,
 			"ListFederatedBundles":       true,
 			"GetFederatedBundle":         true,
@@ -641,6 +651,7 @@ func testBundleAPI(ctx context.Context, t *testing.T, conns testConns) {
 			"GetBundle":                  true,
 			"AppendBundle":               false,
 			"PublishJWTAuthority":        false,
+			"PublishWITAuthority":        false,
 			"CountBundles":               false,
 			"ListFederatedBundles":       false,
 			"GetFederatedBundle":         false,
@@ -656,6 +667,7 @@ func testBundleAPI(ctx context.Context, t *testing.T, conns testConns) {
 			"GetBundle":                  true,
 			"AppendBundle":               false,
 			"PublishJWTAuthority":        false,
+			"PublishWITAuthority":        false,
 			"CountBundles":               false,
 			"ListFederatedBundles":       false,
 			"GetFederatedBundle":         true,
@@ -671,6 +683,7 @@ func testBundleAPI(ctx context.Context, t *testing.T, conns testConns) {
 			"GetBundle":                  true,
 			"AppendBundle":               true,
 			"PublishJWTAuthority":        false,
+			"PublishWITAuthority":        false,
 			"CountBundles":               true,
 			"ListFederatedBundles":       true,
 			"GetFederatedBundle":         true,
@@ -686,6 +699,7 @@ func testBundleAPI(ctx context.Context, t *testing.T, conns testConns) {
 			"GetBundle":                  true,
 			"AppendBundle":               true,
 			"PublishJWTAuthority":        false,
+			"PublishWITAuthority":        false,
 			"CountBundles":               true,
 			"ListFederatedBundles":       true,
 			"GetFederatedBundle":         true,
@@ -701,6 +715,7 @@ func testBundleAPI(ctx context.Context, t *testing.T, conns testConns) {
 			"GetBundle":                  true,
 			"AppendBundle":               false,
 			"PublishJWTAuthority":        true,
+			"PublishWITAuthority":        true,
 			"CountBundles":               false,
 			"ListFederatedBundles":       false,
 			"GetFederatedBundle":         false,
@@ -797,8 +812,10 @@ func testSVIDAPI(ctx context.Context, t *testing.T, conns testConns) {
 		testAuthorization(ctx, t, svidv1.NewSVIDClient(conns.local), map[string]bool{
 			"MintX509SVID":        true,
 			"MintJWTSVID":         true,
+			"MintWITSVID":         true,
 			"BatchNewX509SVID":    false,
 			"NewJWTSVID":          false,
+			"BatchNewWITSVID":     false,
 			"NewDownstreamX509CA": false,
 		})
 	})
@@ -807,8 +824,10 @@ func testSVIDAPI(ctx context.Context, t *testing.T, conns testConns) {
 		testAuthorization(ctx, t, svidv1.NewSVIDClient(conns.noAuth), map[string]bool{
 			"MintX509SVID":        false,
 			"MintJWTSVID":         false,
+			"MintWITSVID":         false,
 			"BatchNewX509SVID":    false,
 			"NewJWTSVID":          false,
+			"BatchNewWITSVID":     false,
 			"NewDownstreamX509CA": false,
 		})
 	})
@@ -817,8 +836,10 @@ func testSVIDAPI(ctx context.Context, t *testing.T, conns testConns) {
 		testAuthorization(ctx, t, svidv1.NewSVIDClient(conns.agent), map[string]bool{
 			"MintX509SVID":        false,
 			"MintJWTSVID":         false,
+			"MintWITSVID":         false,
 			"BatchNewX509SVID":    true,
 			"NewJWTSVID":          true,
+			"BatchNewWITSVID":     true,
 			"NewDownstreamX509CA": false,
 		})
 	})
@@ -827,8 +848,10 @@ func testSVIDAPI(ctx context.Context, t *testing.T, conns testConns) {
 		testAuthorization(ctx, t, svidv1.NewSVIDClient(conns.admin), map[string]bool{
 			"MintX509SVID":        true,
 			"MintJWTSVID":         true,
+			"MintWITSVID":         true,
 			"BatchNewX509SVID":    false,
 			"NewJWTSVID":          false,
+			"BatchNewWITSVID":     false,
 			"NewDownstreamX509CA": false,
 		})
 	})
@@ -837,8 +860,10 @@ func testSVIDAPI(ctx context.Context, t *testing.T, conns testConns) {
 		testAuthorization(ctx, t, svidv1.NewSVIDClient(conns.federatedAdmin), map[string]bool{
 			"MintX509SVID":        true,
 			"MintJWTSVID":         true,
+			"MintWITSVID":         true,
 			"BatchNewX509SVID":    false,
 			"NewJWTSVID":          false,
+			"BatchNewWITSVID":     false,
 			"NewDownstreamX509CA": false,
 		})
 	})
@@ -847,8 +872,10 @@ func testSVIDAPI(ctx context.Context, t *testing.T, conns testConns) {
 		testAuthorization(ctx, t, svidv1.NewSVIDClient(conns.downstream), map[string]bool{
 			"MintX509SVID":        false,
 			"MintJWTSVID":         false,
+			"MintWITSVID":         false,
 			"BatchNewX509SVID":    false,
 			"NewJWTSVID":          false,
+			"BatchNewWITSVID":     false,
 			"NewDownstreamX509CA": true,
 		})
 	})
@@ -937,6 +964,11 @@ func testLocalAuthorityAPI(ctx context.Context, t *testing.T, conns testConns) {
 			"TaintX509UpstreamAuthority":  true,
 			"RevokeX509Authority":         true,
 			"RevokeX509UpstreamAuthority": true,
+			"GetWITAuthorityState":        true,
+			"PrepareWITAuthority":         true,
+			"ActivateWITAuthority":        true,
+			"TaintWITAuthority":           true,
+			"RevokeWITAuthority":          true,
 		})
 	})
 
@@ -954,6 +986,11 @@ func testLocalAuthorityAPI(ctx context.Context, t *testing.T, conns testConns) {
 			"TaintX509UpstreamAuthority":  false,
 			"RevokeX509Authority":         false,
 			"RevokeX509UpstreamAuthority": false,
+			"GetWITAuthorityState":        false,
+			"PrepareWITAuthority":         false,
+			"ActivateWITAuthority":        false,
+			"TaintWITAuthority":           false,
+			"RevokeWITAuthority":          false,
 		})
 	})
 
@@ -971,6 +1008,11 @@ func testLocalAuthorityAPI(ctx context.Context, t *testing.T, conns testConns) {
 			"TaintX509UpstreamAuthority":  false,
 			"RevokeX509Authority":         false,
 			"RevokeX509UpstreamAuthority": false,
+			"GetWITAuthorityState":        false,
+			"PrepareWITAuthority":         false,
+			"ActivateWITAuthority":        false,
+			"TaintWITAuthority":           false,
+			"RevokeWITAuthority":          false,
 		})
 	})
 
@@ -988,6 +1030,11 @@ func testLocalAuthorityAPI(ctx context.Context, t *testing.T, conns testConns) {
 			"TaintX509UpstreamAuthority":  true,
 			"RevokeX509Authority":         true,
 			"RevokeX509UpstreamAuthority": true,
+			"GetWITAuthorityState":        true,
+			"PrepareWITAuthority":         true,
+			"ActivateWITAuthority":        true,
+			"TaintWITAuthority":           true,
+			"RevokeWITAuthority":          true,
 		})
 	})
 
@@ -1005,6 +1052,11 @@ func testLocalAuthorityAPI(ctx context.Context, t *testing.T, conns testConns) {
 			"TaintX509UpstreamAuthority":  true,
 			"RevokeX509Authority":         true,
 			"RevokeX509UpstreamAuthority": true,
+			"GetWITAuthorityState":        true,
+			"PrepareWITAuthority":         true,
+			"ActivateWITAuthority":        true,
+			"TaintWITAuthority":           true,
+			"RevokeWITAuthority":          true,
 		})
 	})
 
@@ -1022,6 +1074,11 @@ func testLocalAuthorityAPI(ctx context.Context, t *testing.T, conns testConns) {
 			"TaintX509UpstreamAuthority":  false,
 			"RevokeX509Authority":         false,
 			"RevokeX509UpstreamAuthority": false,
+			"GetWITAuthorityState":        false,
+			"PrepareWITAuthority":         false,
+			"ActivateWITAuthority":        false,
+			"TaintWITAuthority":           false,
+			"RevokeWITAuthority":          false,
 		})
 	})
 }
@@ -1251,6 +1308,10 @@ func (bundleServer) PublishJWTAuthority(_ context.Context, _ *bundlev1.PublishJW
 	return &bundlev1.PublishJWTAuthorityResponse{}, nil
 }
 
+func (bundleServer) PublishWITAuthority(_ context.Context, _ *bundlev1.PublishWITAuthorityRequest) (*bundlev1.PublishWITAuthorityResponse, error) {
+	return &bundlev1.PublishWITAuthorityResponse{}, nil
+}
+
 func (bundleServer) ListFederatedBundles(_ context.Context, _ *bundlev1.ListFederatedBundlesRequest) (*bundlev1.ListFederatedBundlesResponse, error) {
 	return &bundlev1.ListFederatedBundlesResponse{}, nil
 }
@@ -1363,6 +1424,10 @@ func (svidServer) MintJWTSVID(_ context.Context, _ *svidv1.MintJWTSVIDRequest) (
 	return &svidv1.MintJWTSVIDResponse{}, nil
 }
 
+func (svidServer) MintWITSVID(_ context.Context, _ *svidv1.MintWITSVIDRequest) (*svidv1.MintWITSVIDResponse, error) {
+	return &svidv1.MintWITSVIDResponse{}, nil
+}
+
 func (svidServer) BatchNewX509SVID(_ context.Context, _ *svidv1.BatchNewX509SVIDRequest) (*svidv1.BatchNewX509SVIDResponse, error) {
 	return &svidv1.BatchNewX509SVIDResponse{}, nil
 }
@@ -1371,6 +1436,10 @@ func (svidServer) NewJWTSVID(_ context.Context, _ *svidv1.NewJWTSVIDRequest) (*s
 	return &svidv1.NewJWTSVIDResponse{}, nil
 }
 
+func (svidServer) BatchNewWITSVID(_ context.Context, _ *svidv1.BatchNewWITSVIDRequest) (*svidv1.BatchNewWITSVIDResponse, error) {
+	return &svidv1.BatchNewWITSVIDResponse{}, nil
+}
+
 func (svidServer) NewDownstreamX509CA(_ context.Context, _ *svidv1.NewDownstreamX509CARequest) (*svidv1.NewDownstreamX509CAResponse, error) {
 	return &svidv1.NewDownstreamX509CAResponse{}, nil
 }
@@ -1454,3 +1523,23 @@ func (localAuthorityServer) RevokeX509Authority(context.Context, *localauthority
 func (localAuthorityServer) RevokeX509UpstreamAuthority(context.Context, *localauthorityv1.RevokeX509UpstreamAuthorityRequest) (*localauthorityv1.RevokeX509UpstreamAuthorityResponse, error) {
 	return &localauthorityv1.RevokeX509UpstreamAuthorityResponse{}, nil
 }
+
+func (localAuthorityServer) GetWITAuthorityState(context.Context, *localauthorityv1.GetWITAuthorityStateRequest) (*localauthorityv1.GetWITAuthorityStateResponse, error) {
+	return &localauthorityv1.GetWITAuthorityStateResponse{}, nil
+}
+
+func (localAuthorityServer) PrepareWITAuthority(context.Context, *localauthorityv1.PrepareWITAuthorityRequest) (*localauthorityv1.PrepareWITAuthorityResponse, error) {
+	return &localauthorityv1.PrepareWITAuthorityResponse{}, nil
+}
+
+func (localAuthorityServer) ActivateWITAuthority(context.Context, *localauthorityv1.ActivateWITAuthorityRequest) (*localauthorityv1.ActivateWITAuthorityResponse, error) {
+	return &localauthorityv1.ActivateWITAuthorityResponse{}, nil
+}
+
+func (localAuthorityServer) TaintWITAuthority(context.Context, *localauthorityv1.TaintWITAuthorityRequest) (*localauthorityv1.TaintWITAuthorityResponse, error) {
+	return &localauthorityv1.TaintWITAuthorityResponse{}, nil
+}
+
+func (localAuthorityServer) RevokeWITAuthority(context.Context, *localauthorityv1.RevokeWITAuthorityRequest) (*localauthorityv1.RevokeWITAuthorityResponse, error) {
+	return &localauthorityv1.RevokeWITAuthorityResponse{}, nil
+}
