@@ -9,19 +9,47 @@ import (
 	"crypto/x509"
 	"crypto/x509/pkix"
 	"encoding/pem"
+	"flag"
 	"fmt"
 	"math/big"
+	"net/url"
 	"os"
 	"path/filepath"
+	"strings"
 	"time"
 )
 
+type stringArrayFlag []string
+
+func (s *stringArrayFlag) String() string {
+	return strings.Join(*s, ";")
+}
+
+func (s *stringArrayFlag) Set(value string) error {
+	*s = append(*s, value)
+	return nil
+}
+
 func main() {
-	if len(os.Args) < 3 {
+	var trustDomain string
+	var x509popSans stringArrayFlag
+	flag.StringVar(&trustDomain, "trust-domain", "", "Name of the trust domains the certs will be used for")
+	flag.Var(&x509popSans, "x509pop-san", "Uri san to set using x509pop:// scheme")
+
+	flag.Parse()
+
+	if len(flag.Args()) < 2 {
 		fmt.Fprintln(os.Stderr, "usage: gencerts SERVERDIR AGENTDIR [AGENTDIR...]")
 		os.Exit(1)
 	}
 
+	var x509popSanUris []*url.URL
+	for _, x509popSan := range x509popSans {
+		san, err := url.Parse("x509pop://" + trustDomain + "/" + x509popSan)
+		checkErr(err)
+		x509popSanUris = append(x509popSanUris, san)
+	}
+
 	notAfter := time.Now().Add(time.Hour)
 
 	caKey := generateKey()
@@ -33,15 +61,16 @@ func main() {
 		Subject:               pkix.Name{CommonName: "Agent CA"},
 	})
 
-	writeCerts(filepath.Join(os.Args[1], "agent-cacert.pem"), caCert)
+	writeCerts(filepath.Join(flag.Arg(0), "agent-cacert.pem"), caCert)
 
-	for i, dir := range os.Args[2:] {
+	for i, dir := range flag.Args()[1:] {
 		agentKey := generateKey()
 		agentCert := createCertificate(agentKey, &x509.Certificate{
 			SerialNumber: big.NewInt(int64(i)),
 			KeyUsage:     x509.KeyUsageDigitalSignature,
 			NotAfter:     notAfter,
 			Subject:      pkix.Name{CommonName: filepath.Base(dir)},
+			URIs:         x509popSanUris,
 		}, caKey, caCert)
 
 		writeKey(filepath.Join(dir, "agent.key.pem"), agentKey)
